==> misfortune-0.1.2.1-162.1-loong64.pkg.tar.zst: usr/share/haskell/register/misfortune.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 misfortune
version:              0.1.2.1
visibility:           public
id:                   misfortune-0.1.2.1-2FIDNJUFwWkBWQbIuAMejm
key:                  misfortune-0.1.2.1-2FIDNJUFwWkBWQbIuAMejm
license:              MIT
maintainer:           Naïm Favier <n@monade.li>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/ncfavier/misfortune
synopsis:             fortune-mod clone
description:          fortune-mod clone, in library and executable form.
category:             Console, Game
abi:                  854d32a0d8cab554640f8d411e0bac5e
exposed:              True
exposed-modules:      Data.Fortune
hidden-modules:
    Data.Fortune.FortuneFile Data.Fortune.Index Data.Fortune.Stats
    Paths_misfortune

import-dirs:          /usr/lib/ghc-9.6.6/site-local/misfortune-0.1.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/misfortune-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/misfortune-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/misfortune
hs-libraries:         HSmisfortune-0.1.2.1-2FIDNJUFwWkBWQbIuAMejm
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK directory-1.3.8.5
    filepath-1.4.300.1 knob-0.2.2-C6uO4qMQKGWIGLfyGFLrbG
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm
    random-fu-0.3.0.1-GYabAScmUtEAVvsb95PG2M text-2.0.2
    utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/misfortune/html/misfortune.haddock
haddock-html:         /usr/share/doc/misfortune/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> misfortune-0.1.2.1-163-loong64.pkg.tar.zst: usr/share/haskell/register/misfortune.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 misfortune
version:              0.1.2.1
visibility:           public
id:                   misfortune-0.1.2.1-9mPO7nM8EBvEuSFm9HNPIh
key:                  misfortune-0.1.2.1-9mPO7nM8EBvEuSFm9HNPIh
license:              MIT
maintainer:           Naïm Favier <n@monade.li>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/ncfavier/misfortune
synopsis:             fortune-mod clone
description:          fortune-mod clone, in library and executable form.
category:             Console, Game
abi:                  42df358b0adb2ac14ac85dab6d28556b
exposed:              True
exposed-modules:      Data.Fortune
hidden-modules:
    Data.Fortune.FortuneFile Data.Fortune.Index Data.Fortune.Stats
    Paths_misfortune

import-dirs:          /usr/lib/ghc-9.6.6/site-local/misfortune-0.1.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/misfortune-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/misfortune-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/misfortune
hs-libraries:         HSmisfortune-0.1.2.1-9mPO7nM8EBvEuSFm9HNPIh
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK directory-1.3.8.5
    filepath-1.4.300.1 knob-0.2.2-C6uO4qMQKGWIGLfyGFLrbG
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    random-fu-0.3.0.1-FjYoQXsLrVl4yb84CCphz8 text-2.0.2
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/misfortune/html/misfortune.haddock
haddock-html:         /usr/share/doc/misfortune/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
